"use client"

import type React from "react"

import { useState } from "react"
import type { Store, GroceryItem } from "@/types"
import { Button } from "@/components/ui/button"
import { Input } from "@/components/ui/input"
import { Checkbox } from "@/components/ui/checkbox"
import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card"
import { ScrollArea } from "@/components/ui/scroll-area"
import { Label } from "@/components/ui/label"
import { Tooltip, TooltipContent, TooltipProvider, TooltipTrigger } from "@/components/ui/tooltip"
import { ShoppingCart, Plus, Trash2, Minus, Tag, Check, Search, ShoppingBag } from "lucide-react"
import { useLanguage } from "@/contexts/language-context"
import { motion, AnimatePresence } from "framer-motion"
import { Badge } from "@/components/ui/badge"
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs"
import { Switch } from "@/components/ui/switch"

interface GroceryListProps {
  store: Store
  items: GroceryItem[]
  addItem: (name: string, quantity: number, buyOnSaleOnly: boolean) => void
  toggleItemPurchased: (id: string) => void
  toggleItemSaleOnly: (id: string) => void
  deleteItem: (id: string) => void
  updateItemQuantity: (id: string, change: number) => void
}

const GroceryList: React.FC<GroceryListProps> = ({
  store,
  items,
  addItem,
  toggleItemPurchased,
  toggleItemSaleOnly,
  deleteItem,
  updateItemQuantity,
}) => {
  const { t } = useLanguage()
  const [newItemName, setNewItemName] = useState("")
  const [newItemQuantity, setNewItemQuantity] = useState(1)
  const [newItemSaleOnly, setNewItemSaleOnly] = useState(false)
  const [isAddingItem, setIsAddingItem] = useState(false)
  const [searchQuery, setSearchQuery] = useState("")
  const [filterMode, setFilterMode] = useState<"all" | "active" | "purchased">("all")
  const [showSaleOnly, setShowSaleOnly] = useState(false)

  const handleAddItem = (e: React.FormEvent) => {
    e.preventDefault()
    if (newItemName.trim()) {
      addItem(newItemName, newItemQuantity, newItemSaleOnly)
      setNewItemName("")
      setNewItemQuantity(1)
      setNewItemSaleOnly(false)
      setIsAddingItem(false)
    }
  }

  const handleQuantityChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const value = Number.parseInt(e.target.value, 10)
    setNewItemQuantity(isNaN(value) || value < 1 ? 1 : value)
  }

  // Filter and sort items
  const filteredItems = items
    .filter((item) => {
      // Apply search filter
      if (searchQuery && !item.name.toLowerCase().includes(searchQuery.toLowerCase())) {
        return false
      }

      // Apply tab filter
      if (filterMode === "active" && item.purchased) {
        return false
      }
      if (filterMode === "purchased" && !item.purchased) {
        return false
      }

      // Apply sale only filter
      if (showSaleOnly && !item.buyOnSaleOnly) {
        return false
      }

      return true
    })
    .sort((a, b) => {
      // Sort by purchased status first
      if (a.purchased !== b.purchased) {
        return a.purchased ? 1 : -1
      }
      // Then sort alphabetically
      return a.name.localeCompare(b.name)
    })

  const purchasedCount = items.filter((item) => item.purchased).length
  const saleOnlyCount = items.filter((item) => item.buyOnSaleOnly).length

  return (
    <TooltipProvider>
      <Card className="shadow-lg border-0 bg-white dark:bg-slate-900 overflow-hidden">
        <CardHeader className="bg-gradient-to-r from-emerald-600 to-teal-600 text-white pb-4">
          <div className="flex justify-between items-start">
            <div>
              <CardTitle className="flex items-center gap-2 text-xl">
                <ShoppingCart className="h-5 w-5" /> {store.name}
              </CardTitle>
              <p className="text-sm text-emerald-50 mt-1 opacity-90">
                {t("groceryList") || "Shopping List"} • {items.length} {t("items") || "items"}
              </p>
            </div>
            <Badge
              variant="outline"
              className="bg-white/20 hover:bg-white/30 text-white border-white/40 transition-colors"
            >
              {purchasedCount}/{items.length} {t("purchased") || "purchased"}
            </Badge>
          </div>
        </CardHeader>

        <CardContent className="p-0">
          {/* Add Item Section */}
          <div className="p-4 bg-emerald-50 dark:bg-slate-800/50">
            {isAddingItem ? (
              <motion.form
                initial={{ opacity: 0, y: -10 }}
                animate={{ opacity: 1, y: 0 }}
                onSubmit={handleAddItem}
                className="space-y-3"
              >
                <div className="flex gap-2">
                  <Input
                    type="text"
                    value={newItemName}
                    onChange={(e) => setNewItemName(e.target.value)}
                    placeholder={t("enterItemName") || "Item name"}
                    className="flex-grow border-emerald-200 focus-visible:ring-emerald-500"
                    autoFocus
                  />
                  <Input
                    type="number"
                    value={newItemQuantity}
                    onChange={handleQuantityChange}
                    min="1"
                    className="w-20 text-center border-emerald-200 focus-visible:ring-emerald-500"
                  />
                </div>

                <div className="flex items-center justify-between">
                  <div className="flex items-center space-x-2">
                    <Checkbox
                      id="saleOnly"
                      checked={newItemSaleOnly}
                      onCheckedChange={(checked) => setNewItemSaleOnly(Boolean(checked))}
                      className="data-[state=checked]:bg-emerald-500 data-[state=checked]:border-emerald-500"
                    />
                    <Label htmlFor="saleOnly" className="text-sm cursor-pointer flex items-center gap-1">
                      {t("onSaleOnly") || "Buy only on sale"}
                      <Tag size={12} className="text-emerald-500" />
                    </Label>
                  </div>

                  <div className="flex gap-2">
                    <Button
                      type="button"
                      variant="ghost"
                      size="sm"
                      onClick={() => setIsAddingItem(false)}
                      className="text-slate-600 dark:text-slate-400"
                    >
                      {t("cancel") || "Cancel"}
                    </Button>
                    <Button
                      type="submit"
                      size="sm"
                      className="bg-emerald-600 hover:bg-emerald-700 text-white"
                      disabled={!newItemName.trim()}
                    >
                      <Plus className="mr-1 h-4 w-4" />
                      {t("addItem") || "Add Item"}
                    </Button>
                  </div>
                </div>
              </motion.form>
            ) : (
              <Button
                onClick={() => setIsAddingItem(true)}
                className="w-full bg-white hover:bg-emerald-50 text-emerald-700 border border-emerald-200 hover:border-emerald-300 dark:bg-slate-800 dark:text-emerald-400 dark:border-slate-700 dark:hover:bg-slate-700"
              >
                <Plus className="mr-2 h-4 w-4" />
                {t("addItem") || "Add New Item"}
              </Button>
            )}
          </div>

          {/* Search and Filter */}
          <div className="px-4 py-3 border-y border-slate-200 dark:border-slate-700">
            <div className="flex flex-col sm:flex-row gap-3">
              <div className="relative flex-grow">
                <Search className="absolute left-2.5 top-2.5 h-4 w-4 text-slate-400" />
                <Input
                  type="text"
                  placeholder={t("searchItems") || "Search items..."}
                  value={searchQuery}
                  onChange={(e) => setSearchQuery(e.target.value)}
                  className="pl-9 h-9 text-sm border-slate-200 dark:border-slate-700"
                />
              </div>
              <div className="flex items-center gap-2">
                <Tooltip>
                  <TooltipTrigger asChild>
                    <div className="flex items-center space-x-2">
                      <Switch
                        id="sale-filter"
                        checked={showSaleOnly}
                        onCheckedChange={setShowSaleOnly}
                        className="data-[state=checked]:bg-emerald-500"
                      />
                      <Label htmlFor="sale-filter" className="text-sm cursor-pointer flex items-center gap-1">
                        <Tag size={12} className="text-emerald-500" />
                      </Label>
                    </div>
                  </TooltipTrigger>
                  <TooltipContent>
                    <p>{t("showOnlySaleItems") || "Show only sale items"}</p>
                  </TooltipContent>
                </Tooltip>

                <Badge variant="outline" className="text-xs font-normal">
                  {saleOnlyCount} {t("onSale") || "on sale"}
                </Badge>
              </div>
            </div>
          </div>

          {/* Tabs */}
          <Tabs defaultValue="all" className="w-full" onValueChange={(value) => setFilterMode(value as any)}>
            <div className="border-b border-slate-200 dark:border-slate-700">
              <TabsList className="h-11 w-full rounded-none bg-transparent border-b border-slate-200 dark:border-slate-700">
                <TabsTrigger
                  value="all"
                  className="flex-1 data-[state=active]:bg-transparent data-[state=active]:text-emerald-700 dark:data-[state=active]:text-emerald-500 data-[state=active]:shadow-none data-[state=active]:border-b-2 data-[state=active]:border-emerald-500 rounded-none h-11"
                >
                  {t("all") || "All"}
                  <Badge className="ml-2 bg-slate-200 text-slate-700 dark:bg-slate-700 dark:text-slate-300">
                    {items.length}
                  </Badge>
                </TabsTrigger>
                <TabsTrigger
                  value="active"
                  className="flex-1 data-[state=active]:bg-transparent data-[state=active]:text-emerald-700 dark:data-[state=active]:text-emerald-500 data-[state=active]:shadow-none data-[state=active]:border-b-2 data-[state=active]:border-emerald-500 rounded-none h-11"
                >
                  {t("active") || "Active"}
                  <Badge className="ml-2 bg-slate-200 text-slate-700 dark:bg-slate-700 dark:text-slate-300">
                    {items.length - purchasedCount}
                  </Badge>
                </TabsTrigger>
                <TabsTrigger
                  value="purchased"
                  className="flex-1 data-[state=active]:bg-transparent data-[state=active]:text-emerald-700 dark:data-[state=active]:text-emerald-500 data-[state=active]:shadow-none data-[state=active]:border-b-2 data-[state=active]:border-emerald-500 rounded-none h-11"
                >
                  {t("purchased") || "Purchased"}
                  <Badge className="ml-2 bg-slate-200 text-slate-700 dark:bg-slate-700 dark:text-slate-300">
                    {purchasedCount}
                  </Badge>
                </TabsTrigger>
              </TabsList>
            </div>

            <TabsContent value="all" className="m-0">
              <ItemsList
                items={filteredItems}
                toggleItemPurchased={toggleItemPurchased}
                toggleItemSaleOnly={toggleItemSaleOnly}
                deleteItem={deleteItem}
                updateItemQuantity={updateItemQuantity}
                t={t as (key: string) => string}
              />
            </TabsContent>
            <TabsContent value="active" className="m-0">
              <ItemsList
                items={filteredItems}
                toggleItemPurchased={toggleItemPurchased}
                toggleItemSaleOnly={toggleItemSaleOnly}
                deleteItem={deleteItem}
                updateItemQuantity={updateItemQuantity}
                t={t as (key: string) => string}
              />
            </TabsContent>
            <TabsContent value="purchased" className="m-0">
              <ItemsList
                items={filteredItems}
                toggleItemPurchased={toggleItemPurchased}
                toggleItemSaleOnly={toggleItemSaleOnly}
                deleteItem={deleteItem}
                updateItemQuantity={updateItemQuantity}
                t={t as (key: string) => string}
              />
            </TabsContent>
          </Tabs>
        </CardContent>
      </Card>
    </TooltipProvider>
  )
}

interface ItemsListProps {
  items: GroceryItem[]
  toggleItemPurchased: (id: string) => void
  toggleItemSaleOnly: (id: string) => void
  deleteItem: (id: string) => void
  updateItemQuantity: (id: string, change: number) => void
  t: (key: string) => string
}

const ItemsList: React.FC<ItemsListProps> = ({
  items,
  toggleItemPurchased,
  toggleItemSaleOnly,
  deleteItem,
  updateItemQuantity,
  t,
}) => {
  if (items.length === 0) {
    return (
      <div className="flex flex-col items-center justify-center py-12 px-4 text-center">
        <div className="w-16 h-16 rounded-full bg-emerald-100 dark:bg-emerald-900/30 flex items-center justify-center mb-3">
          <ShoppingBag className="h-8 w-8 text-emerald-500 dark:text-emerald-400" />
        </div>
        <p className="text-slate-600 dark:text-slate-400 mb-1">{t("noItemsFound") || "No items found"}</p>
        <p className="text-xs text-slate-500 dark:text-slate-500">
          {t("tryDifferentSearch") || "Try a different search or add new items"}
        </p>
      </div>
    )
  }

  return (
    <ScrollArea className="h-[350px]">
      <ul className="divide-y divide-slate-100 dark:divide-slate-800">
        <AnimatePresence>
          {items.map((item) => (
            <motion.li
              key={item.id}
              initial={{ opacity: 0, height: 0 }}
              animate={{ opacity: 1, height: "auto" }}
              exit={{ opacity: 0, height: 0 }}
              transition={{ duration: 0.2 }}
              className={`transition-all ${item.purchased ? "bg-slate-50 dark:bg-slate-800/50" : ""}`}
            >
              <div className="p-3 sm:p-4">
                <div className="flex items-start justify-between">
                  <div className="flex items-start gap-3">
                    <div className="mt-0.5">
                      <Checkbox
                        id={`item-purchased-${item.id}`}
                        checked={item.purchased}
                        onCheckedChange={() => toggleItemPurchased(item.id)}
                        className="h-5 w-5 rounded-full data-[state=checked]:bg-emerald-500 data-[state=checked]:border-emerald-500"
                      >
                        <Check className="h-3 w-3" />
                      </Checkbox>
                    </div>
                    <div>
                      <Label
                        htmlFor={`item-purchased-${item.id}`}
                        className={`text-base font-medium cursor-pointer ${item.purchased
                          ? "line-through text-slate-500 dark:text-slate-500"
                          : "text-slate-800 dark:text-slate-200"
                          }`}
                      >
                        {item.name}
                      </Label>
                      <div className="flex items-center gap-2 mt-1">
                        {item.buyOnSaleOnly && (
                          <Badge className="bg-emerald-100 hover:bg-emerald-200 text-emerald-700 dark:bg-emerald-900/30 dark:text-emerald-400 dark:hover:bg-emerald-900/50">
                            <Tag size={10} className="mr-1" />
                            {t("onSaleOnly") || "On sale only"}
                          </Badge>
                        )}
                        <span className="text-xs text-slate-500 dark:text-slate-500">
                          {t("quantity") || "Qty"}: {item.quantity}
                        </span>
                      </div>
                    </div>
                  </div>

                  <div className="flex items-center gap-1">
                    <Tooltip>
                      <TooltipTrigger asChild>
                        <Button
                          variant="ghost"
                          size="icon"
                          className={`h-8 w-8 rounded-full ${item.buyOnSaleOnly
                            ? "bg-emerald-100 text-emerald-700 hover:bg-emerald-200 dark:bg-emerald-900/30 dark:text-emerald-400 dark:hover:bg-emerald-900/50"
                            : "text-slate-400 hover:text-emerald-600 hover:bg-emerald-50 dark:hover:bg-emerald-900/20"
                            }`}
                          onClick={() => toggleItemSaleOnly(item.id)}
                        >
                          <Tag size={14} />
                        </Button>
                      </TooltipTrigger>
                      <TooltipContent>
                        <p>
                          {item.buyOnSaleOnly
                            ? t("removeFromSale") || "Remove sale tag"
                            : t("markAsSaleOnly") || "Mark as sale only"}
                        </p>
                      </TooltipContent>
                    </Tooltip>

                    <div className="flex items-center border border-slate-200 dark:border-slate-700 rounded-full">
                      <Button
                        variant="ghost"
                        size="icon"
                        className="h-7 w-7 rounded-full text-slate-500 hover:text-slate-700 dark:text-slate-400 dark:hover:text-slate-300"
                        onClick={() => updateItemQuantity(item.id, -1)}
                        disabled={item.quantity <= 1}
                      >
                        <Minus size={12} />
                      </Button>
                      <span className="w-6 text-center text-sm font-medium tabular-nums text-slate-700 dark:text-slate-300">
                        {item.quantity}
                      </span>
                      <Button
                        variant="ghost"
                        size="icon"
                        className="h-7 w-7 rounded-full text-slate-500 hover:text-slate-700 dark:text-slate-400 dark:hover:text-slate-300"
                        onClick={() => updateItemQuantity(item.id, 1)}
                      >
                        <Plus size={12} />
                      </Button>
                    </div>

                    <Tooltip>
                      <TooltipTrigger asChild>
                        <Button
                          variant="ghost"
                          size="icon"
                          className="h-8 w-8 rounded-full text-slate-400 hover:text-red-500 hover:bg-red-50 dark:hover:bg-red-900/20"
                          onClick={() => deleteItem(item.id)}
                        >
                          <Trash2 size={14} />
                        </Button>
                      </TooltipTrigger>
                      <TooltipContent>
                        <p>{t("deleteItem") || "Delete item"}</p>
                      </TooltipContent>
                    </Tooltip>
                  </div>
                </div>
              </div>
            </motion.li>
          ))}
        </AnimatePresence>
      </ul>
    </ScrollArea>
  )
}

export default GroceryList
